@@ -1,3 +1,4 @@
+#!/bin/sh
 #
 #  Common shell functions which may be used by any hook script
 #
@@ -21,7 +22,7 @@ logMessage ()
     message="$*"
 
     if [ ! -z "${verbose}" ]; then
-	echo $message
+        echo $message
     fi
 }
 
@@ -31,21 +32,21 @@ logMessage ()
 #  Test the given condition is true, and if not abort.
 #
 #  Sample usage:
-#    assert $LINENO "${verbose}"
+#    assert "$LINENO" "${verbose}"
 #
 assert ()
 {
     lineno="?"
 
     if [ -n "${LINENO}" ]; then
-    	# our shell defines variable LINENO, great!
-	lineno=$1
-	shift
+        # our shell defines variable LINENO, great!
+        lineno=$1
+        shift
     fi
 
     if [ ! $* ] ; then
         echo "assert failed: $0:$lineno [$*]"
-	exit
+        exit
     fi
 }
 
@@ -66,23 +67,73 @@ installDebianPackage ()
     #
     #  We require a package + prefix
     #
-    assert $LINENO "${package}"
-    assert $LINENO "${prefix}"
+    assert "$LINENO" "${package}"
+    assert "$LINENO" "${prefix}"
 
     #
     # Prefix must be a directory.
     #
-    assert $LINENO -d ${prefix}
+    assert "$LINENO" -d ${prefix}
+
+    #
+    # Disable the start-stop-daemon
+    #
+    disableStartStopDaemon ${prefix}
 
     #
     # Install the package
     #
     DEBIAN_FRONTEND=noninteractive chroot ${prefix} /usr/bin/apt-get --yes --force-yes install ${package}
 
+    #
+    # Re-enable the start-stop-daemon
+    #
+    enableStartStopDaemon ${prefix}
+
 }
 
 
 
+#
+# Disable the start-stop-daemon
+#
+disableStartStopDaemon ()
+{
+   local prefix="$1"
+   assert "$LINENO" "${prefix}"
+   local daemonfile="${prefix}/sbin/start-stop-daemon"
+
+   mv "${daemonfile}" "${daemonfile}.REAL"
+   echo '#!/bin/sh' > "${daemonfile}"
+   echo "echo \"Warning: Fake start-stop-daemon called, doing nothing\"" >> "${daemonfile}"
+
+   chmod 755 "${daemonfile}"
+   logMessage "Start Stop Daemon disabled off."
+}
+ 
+
+
+#
+# Enable the start-stop-daemon
+#
+enableStartStopDaemon ()
+{
+   local prefix=$1
+   assert "$LINENO" "${prefix}"
+   local daemonfile="${prefix}/sbin/start-stop-daemon"
+
+   #
+   #  If the disabled file is present then enable it.
+   #
+   if [ -e "${daemonfile}.REAL" ]; then
+       mv "${daemonfile}.REAL" "${daemonfile}"
+       logMessage "Start Stop Daemon enabled on."
+   fi
+
+}
+ 
+
+
 #
 #  Remove a Debian package.
 #
@@ -99,13 +150,13 @@ removeDebianPackage ()
     #
     #  We require a package + prefix
     #
-    assert $LINENO "${package}"
-    assert $LINENO "${prefix}"
+    assert "$LINENO" "${package}"
+    assert "$LINENO" "${prefix}"
 
     #
     # Prefix must be a directory.
     #
-    assert $LINENO -d ${prefix}
+    assert "$LINENO" -d ${prefix}
 
     #
     # Purge the package
@@ -131,13 +182,13 @@ installCentOS4Package ()
     #
     #  We require a package + prefix
     #
-    assert $LINENO "${package}"
-    assert $LINENO "${prefix}"
+    assert "$LINENO" "${package}"
+    assert "$LINENO" "${prefix}"
 
     #
     # Prefix must be a directory.
     #
-    assert $LINENO -d ${prefix}
+    assert "$LINENO" -d ${prefix}
 
     #
     # Install the package
